/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 18/10/22.
//

#ifndef FGGL_DATA_ASSIMP_MODULE_HPP
#define FGGL_DATA_ASSIMP_MODULE_HPP

#include "fggl/modules/module.hpp"
#include "fggl/assets/loader.hpp"
#include "fggl/data/texture.hpp"

namespace fggl::data::models {

	constexpr auto MODEL_PROVIDER = modules::make_service("fggl::data::Model");
	constexpr auto ASSIMP_MODEL = assets::AssetType::make("model::assimp");

	struct AssimpModule {
		constexpr static const char *name = "fggl::data::Assimp";
		constexpr static const std::array<modules::ModuleService, 1> provides = {
			MODEL_PROVIDER
		};
		constexpr static const std::array<modules::ModuleService, 1> depends = {
			assets::Loader::service
		};
		static bool factory(modules::ModuleService service, modules::Services &serviceManager);
	};

}

namespace fggl::data {
	using AssimpLoader = models::AssimpModule;
}

#endif //FGGL_DATA_ASSIMP_MODULE_HPP
